@@ -2,6 +2,7 @@
 #' @description Returns a data frame that uses data from the Consumer Price Index (All Goods) to convert the value of a US Dollar [$1.00 USD] over time.
 #' @param base_year = A string or integer argument to represent the base year that you would like dollar values converted to. 
 #' For example, if you want to see the value of a 2007 dollar in 2015, you would select 2015 as a base year and find 2007 in the table.
+#' @param ... additional arguments
 #' @keywords bls api economics cpi unemployment inflation
 #' @importFrom stats aggregate
 #' @importFrom dplyr mutate select rename
@@ -13,7 +14,7 @@
 #' values <- inflation_adjust(base_year = 2015)
 #' 
 #' 
-inflation_adjust <- function(base_year=NA){
+inflation_adjust <- function(base_year=NA, ...){
     # Set some dummy variables. This keeps CRAN check happy.
     series_id=period=index=coredata=footnote_codes=value=Group.1=x=year=NULL
     if (nchar(base_year) != 4){
